15.36. cdist-type__docker(7) — cdist 4.10.4 documentation

# 15.36. cdist-type__docker(7)

## 15.36.1. NAME

cdist-type__docker - install Docker CE

## 15.36.2. DESCRIPTION

Installs latest Docker Community Edition package.

## 15.36.3. REQUIRED PARAMETERS

None.

## 15.36.4. OPTIONAL PARAMETERS

state
  'present' or 'absent', defaults to 'present'

## 15.36.5. BOOLEAN PARAMETERS

None.

## 15.36.6. EXAMPLES

    # Install docker
    __docker

    # Remove docker
    __docker --state absent

## 15.36.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.36.8. COPYING

Copyright (C) 2016 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).